@@ -13,4 +13,14 @@ __all__ = ["bingsearch",
            "dogpilesearch",
            "baidusearch",
            "yahoosearch",
-           "googleCSE"]
+           "netcraft",
+           "crtsh",
+           "virustotal",
+           "threatcrowd",
+           "wfuzz_search",
+           "port_scanner",
+           "takeover",
+           "googlecertificates",
+           "googleCSE",
+           "censys",
+           "trello"]
\ No newline at end of file
