@@ -1,9 +1,8 @@
-import string
-import httplib
-import sys
 import myparser
 import re
-
+import requests
+import time
+from discovery.constants import *
 
 class search_ask:
 
@@ -13,23 +12,19 @@ class search_ask:
         self.totalresults = ""
         self.server = "www.ask.com"
         self.hostname = "www.ask.com"
-        self.userAgent = "(Mozilla/5.0 (Windows; U; Windows NT 6.0;en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6"
         self.quantity = "100"
         self.limit = int(limit)
         self.counter = 0
 
     def do_search(self):
-        h = httplib.HTTP(self.server)
-        h.putrequest(
-            'GET',
-            "/web?q=%40" +
-            self.word +
-            "&pu=100&page=" +
-            self.counter)
-        h.putheader('User-agent', self.userAgent)
-        h.endheaders()
-        returncode, returnmsg, headers = h.getreply()
-        self.results = h.getfile().read()
+        headers = {
+            'User-agent': getUserAgent()
+        }
+        url = 'http://' + self.server + '/web?q=%40' + self.word \
+              + "&pu=100&page=" + str(self.counter)
+        h = requests.get(url=url, headers=headers)
+        time.sleep(getDelay())
+        self.results = h.text
         self.totalresults += self.results
 
     def check_next(self):
