@@ -1,8 +1,7 @@
-import httplib
 import myparser
 import time
-import sys
-
+import requests
+from discovery.constants import *
 
 class search_dogpile:
 
@@ -11,29 +10,25 @@ class search_dogpile:
         self.total_results = ""
         self.server = "www.dogpile.com"
         self.hostname = "www.dogpile.com"
-        self.userAgent = "(Mozilla/5.0 (Windows; U; Windows NT 6.0;en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6"
         self.limit = limit
         self.counter = 0
 
     def do_search(self):
-        h = httplib.HTTP(self.server)
-
         # Dogpile is hardcoded to return 10 results
-        h.putrequest('GET', "/search/web?qsi=" + str(self.counter)
-                     + "&q=\"%40" + self.word + "\"")
-        h.putheader('Host', self.hostname)
-        h.putheader('User-agent', self.userAgent)
-        h.endheaders()
-        returncode, returnmsg, headers = h.getreply()
-
-        self.total_results += h.getfile().read()
+        url = 'http://' + self.server + "/search/web?qsi=" + str(self.counter) \
+              + "&q=\"%40" + self.word + "\""
+        headers = {
+            'Host': self.hostname,
+            'User-agent': getUserAgent()
+        }
+        h = requests.get(url=url, headers=headers)
+        self.total_results += h.text
 
     def process(self):
         while self.counter <= self.limit and self.counter <= 1000:
             self.do_search()
-            time.sleep(1)
-
-            print "\tSearching " + str(self.counter) + " results..."
+            time.sleep(getDelay())
+            print("\tSearching " + str(self.counter) + " results...")
             self.counter += 10
 
     def get_emails(self):
