@@ -1,10 +1,6 @@
-import string
-import httplib
-import sys
 import myparser
-import re
-import time
-
+import requests
+from discovery.constants import *
 
 class search_google_labs:
 
@@ -13,7 +9,6 @@ class search_google_labs:
         self.totalresults = ""
         self.server = "labs.google.com"
         self.hostname = "labs.google.com"
-        self.userAgent = "(Mozilla/5.0 (Windows; U; Windows NT 6.0;en-US; rv:1.9.2) Gecko/20100115 Firefox/3.6"
         id = 0
         self.set = ""
         for x in list:
@@ -24,13 +19,13 @@ class search_google_labs:
                 self.set = self.set + "&q" + str(id) + "=" + str(x)
 
     def do_search(self):
-        h = httplib.HTTP(self.server)
-        h.putrequest('GET', "/sets?hl=en&" + self.set)
-        h.putheader('Host', self.hostname)
-        h.putheader('User-agent', self.userAgent)
-        h.endheaders()
-        returncode, returnmsg, headers = h.getreply()
-        self.results = h.getfile().read()
+        url = 'http://' + self.server + "/sets?hl-en&" + self.set
+        headers = {
+            'Host': self.server,
+            'User-agent': getUserAgent()
+        }
+        h = requests.get(url=url, headers=headers)
+        self.results = h.text
         self.totalresults += self.results
 
     def get_set(self):
