@@ -1,9 +1,7 @@
-import string
 import requests
-import sys
 import myparser
-import re
-
+from discovery.constants import *
+import time
 
 class search_linkedin:
 
@@ -20,13 +18,14 @@ class search_linkedin:
     def do_search(self):
         try:
             urly="http://"+ self.server + "/search?num=100&start=" + str(self.counter) + "&hl=en&meta=&q=site%3Alinkedin.com/in%20" + self.word
-        except Exception, e:
-            print e
+        except Exception as e:
+            print(e)
         try:
-            r=requests.get(urly)
-        except Exception,e:
-            print e
-        self.results = r.content
+            headers = {'User-Agent': getUserAgent()}
+            r=requests.get(urly,headers=headers)
+        except Exception as e:
+            print(e)
+        self.results = r.text
         self.totalresults += self.results
 
     def get_people(self):
@@ -36,5 +35,6 @@ class search_linkedin:
     def process(self):
         while (self.counter < self.limit):
             self.do_search()
+            time.sleep(getDelay())
             self.counter += 100
-            print "\tSearching " + str(self.counter) + " results.."
+            print("\tSearching " + str(self.counter) + " results..")
