@@ -21,9 +21,6 @@ ideas or questions to nogradi at gmail dot com.
 Installation: drop markup.py somewhere into your Python path.
 """ % ( __version__, __date__ )
 
-import string
-
-
 class element:
 
     """This class handles the addition of a new element."""
@@ -73,7 +70,7 @@ class element:
         """Append the actual tags to content."""
 
         out = "<%s" % tag
-        for key, value in kwargs.iteritems():
+        for key, value in kwargs.items():
             # when value is None that means stuff like <... checked>
             if value is not None:
                 # strip this so class_ will mean class, etc.
@@ -188,17 +185,17 @@ class page:
 
         if mode == 'strict_html' or mode == 'html':
             self.onetags = valid_onetags
-            self.onetags += map(string.lower, self.onetags)
+            self.onetags += [str.lower(x) for x in self.onetags]
             self.twotags = valid_twotags
-            self.twotags += map(string.lower, self.twotags)
+            self.twotags += [str.lower(x) for x in self.twotags]
             self.deptags = deprecated_onetags + deprecated_twotags
-            self.deptags += map(string.lower, self.deptags)
+            self.deptags += [str.lower(x) for x in self.deptags]
             self.mode = 'strict_html'
         elif mode == 'loose_html':
             self.onetags = valid_onetags + deprecated_onetags
-            self.onetags += map(string.lower, self.onetags)
+            self.onetags += [str.lower(x) for x in self.onetags]
             self.twotags = valid_twotags + deprecated_twotags
-            self.twotags += map(string.lower, self.twotags)
+            self.onetags += [str.lower(x) for x in self.twotags]
             self.mode = mode
         elif mode == 'xml':
             if onetags and twotags:
@@ -347,7 +344,7 @@ class page:
         """This convenience function is only useful for html.
         It adds css stylesheet(s) to the document via the <link> element."""
 
-        if isinstance(filelist, basestring):
+        if isinstance(filelist, str):
             self.link(
                 href=filelist,
                 rel='stylesheet',
@@ -367,7 +364,7 @@ class page:
         a dictionary of the form { 'name':'content' }."""
 
         if isinstance(mydict, dict):
-            for name, content in mydict.iteritems():
+            for name, content in mydict.items():
                 self.meta(name=name, content=content)
         else:
             raise TypeError(
@@ -378,7 +375,7 @@ class page:
         be rendered as <script type='text/type' src=src></script>"""
 
         if isinstance(mydict, dict):
-            for src, type in mydict.iteritems():
+            for src, type in mydict.items():
                 self.script('', src=src, type='text/%s' % type)
         else:
             raise TypeError(
@@ -413,12 +410,10 @@ def _argsdicts(args, mydict):
     else:
         raise Exception("We should have never gotten here.")
 
-    mykeys = mydict.keys()
-    myvalues = map(_totuple, mydict.values())
-
-    maxlength = max(map(len, [args] + myvalues))
-
-    for i in xrange(maxlength):
+    mykeys = list(mydict.keys())
+    myvalues = list(map(_totuple, list(mydict.values())))
+    maxlength = max(list(map(len, [args] + myvalues)))
+    for i in range(maxlength):
         thisdict = {}
         for key, value in zip(mykeys, myvalues):
             try:
@@ -436,7 +431,7 @@ def _argsdicts(args, mydict):
 def _totuple(x):
     """Utility stuff to convert string, int, float, None or anything to a usable tuple."""
 
-    if isinstance(x, basestring):
+    if isinstance(x, str):
         out = x,
     elif isinstance(x, (int, float)):
         out = str(x),
@@ -451,7 +446,7 @@ def _totuple(x):
 def escape(text, newline=False):
     """Escape special html characters."""
 
-    if isinstance(text, basestring):
+    if isinstance(text, str):
         if '&' in text:
             text = text.replace('&', '&amp;')
         if '>' in text:
@@ -474,7 +469,7 @@ _escape = escape
 def unescape(text):
     """Inverse of escape."""
 
-    if isinstance(text, basestring):
+    if isinstance(text, str):
         if '&amp;' in text:
             text = text.replace('&amp;', '&')
         if '&gt;' in text:
@@ -558,4 +553,4 @@ class CustomizationError(MarkupError):
         self.message = "If you customize the allowed elements, you must define both types 'onetags' and 'twotags'."
 
 if __name__ == '__main__':
-    print __doc__
+    print(__doc__)
